<?php
// This file is part of DENIF, distributed under license GPLv3.
// Copyright 2006 Guillaume Ryder, Arthur Charguraud

require_once 'shared.inc.php';


// The contact form is available only if the server can send emails.
bCanSendEmail or die('The contact form is disabled.');


class PageContact extends PageDenif
{
	public $bPropose;
	private $sResult;
	
	
	protected function getParameters() { return concatLists(parent::getParameters(), 'bPropose'); }
	
	
	protected function initialize()
	{
		parent::initialize();
		$this->loadParameters();
		$this->processSendMail();
	}
	
	
	protected function getTitle() { return ($this->bPropose) ? 'Proposer de nouveaux documents' : 'Contacter un administrateur'; }
	
	
	protected function scripts()
	{
		return parent::scripts() .
			html::jscriptLink('global.js') .
			html::jscriptInline('catchLoad(function() { unobfuscateMail(id("contact-mail")); });');
	}
	
	
	protected function contents()
	{
		$s = $this->putTitle($this->getTitle());
		
		$sEmail = html::kbd(obfuscateMail(sContactEmail), attr::id('contact-mail'));
		
		if ($this->bPropose) {
			$s .= html::par('Collez ici un ou plusieurs liens vers les pages o lon peut trouver les documents.' . html::br() . 'Il nest pas ncessaire de mettre un lien pour chaque fichier, un lien vers une page contenant une liste de documents suffit.');
			$s .= $this->getSendMessage(
				'Liste dURL',
				'Votre adresse e-mail pour tre prvenu lorsque lajout aura t effectu (facultatif)');
			$s .= html::par('Note&nbsp;: vous pouvez aussi contacter directement les administrateurs  ladresse ' . $sEmail . '.');
			
		}else{
			$s .= html::par('Envoyez un email  ' . $sEmail . ' ou bien utilisez le formulaire ci-dessous&nbsp;:');
			$s .= $this->getSendMessage(
				'Votre message',
				'Votre adresse e-mail si vous souhaitez une rponse (facultatif)');
		}
		
		return $s;
	}
	
	
	/// Write a message sending form.
	private function getSendMessage($sMessageLabel, $sEmailLabel)
	{
		$s = '';
		
		$s .= $this->getSelfTarget(targetParams)->form(form::METHOD_POST, html::div(
				form::hidden('bSend', '1') .
				form::label('sText', $sMessageLabel . '&nbsp;:') .
				form::textArea('IDsText', 80, 10, html::text($_POST->getSafe('sText'))) .
				form::label('sEmail', $sEmailLabel . '&nbsp;: ') .
				form::text('IDsEmail', $_POST->getSafe('sEmail'), 50, maxLengthEmail) .
				html::div(form::submit('', 'Envoyer le message'), attr::className('form-bottom'))),
			attr::className('form-sendmail'));
		
		$s .= $this->sResult;
		
		return $s;
	}
	
	
	/// Process a message sending form.
	private function processSendMail()
	{
		if (!$_POST->getSafe('bSend')) {
			$this->sResult = '';
			return;
		}
		
		$sSubject = ($this->bPropose) ? sEmailSubjectPropose : sEmailSubjectContact;
		
		$sMessage = trim($_POST->getSafe('sText'));
		if (!$sMessage) {
			$this->sResult = html::div('Veuillez entrer un message.', attr::className('error'));
			return;
		}
		
		$sEmail = trim($_POST->getSafe('sEmail'));
		if ($sEmail) {
			if (strlen($sEmail) > maxLengthEmail || !eregi(sEmailRegexp, $sEmail)) {
				$this->sResult = html::div('Adresse e-mail invalide.', attr::className('error'));
				return;
			}
		}else
			$sEmail = sContactEmail;
		
		$sHeaders = 'From: ' . $sEmail . CRLF . 'Reply-To: ' . $sEmail;
		
		$this->sResult = (@mail(sContactEmail, $sSubject, $sMessage, $sHeaders))
			? html::div('Votre message a bien t envoy, merci&nbsp;!', attr::className('ok'))
			: html::div('Le message na pas pu tre envoy.' . html::br() . 'Merci de contacter directement un administrateur par e-mail.', attr::className('error'));
	}
}

Page::output(new PageContact);

?>