<?php
// This file is part of DENIF, distributed under license GPLv3.
// Copyright 2006 Guillaume Ryder, Arthur Charguraud

require_once 'shared.inc.php';


class PageMoveNode extends PageDenif
{
	public $idSource, $idDest, $sReturnURL;
	
	
	protected function getParameters() { return concatLists(parent::getParameters(), 'idSource;idDest;sReturnURL'); }
	
	protected function getTitle() { return 'Dplacer un nud'; }
	
	protected function getCurrentNodeID() { return $this->idSource; }
	
	
	protected function initialize()
	{
		parent::initialize();
		$this->loadParameters();
		
		$this->needAdmin();
	}
	
	
	protected function contents()
	{
		$s = $this->putTitle($this->getTitle());
		
		// Form
		$form = new FormManager($this);
		$form->pushElement(form::label('idSource', 'ID du nud  dplacer'),
			form::text('IDidSource', $this->idSource, 10, maxLengthID), 'Nud source');
		$form->pushElement(form::label('idDest', 'ID du nouveau parent'),
			form::text('IDidDest', $this->idDest, 10, maxLengthID), 'Nud de destination');
		$form->pushCheckbox('bInsertAtEnd', 'Insrer le nud en dernire position', 'Si dcoch, ajoute le nud en premire position du nouveau parent');
		$form->pushElement('',
			form::submit('bTest', 'Tester le dplacement') . ' ' . form::submit('bMove', 'Dplacer'));
		if ($this->sReturnURL)
			$form->pushElement('', $this->linkTarget($this->targetFromURL($this->sReturnURL), 'Retour'));
		
		$s .= $this->getSelfTarget(targetSession)->form(form::METHOD_GET,
			form::hidden('sReturnURL', $this->sReturnURL) .
			$form->html());
		
		$s .= html::par('Vous pouvez connatre lID dun nud en passant la souris sur son icne ' . DenifLink::createAction('#', 'details', 'Dtails (ID = )')->html() . '.');
		
		// Get the nodes and display information about them
		$aError = array();
		$nodeSource = $this->loadNode($this->idSource, 'nud  dplacer', $sInfoSource, $aError);
		$nodeDest   = $this->loadNode($this->idDest,   'nouveau parent',  $sInfoDest,   $aError);
		
		$bMove = $_REQUEST->getSafe('bMove');
		
		if (!$bMove)
			$s .= html::div($sInfoSource . $sInfoDest, attr::className('form-bottom'));
		
		if ($nodeSource && $nodeDest) {
			if ($nodeSource->iNode != $nodeDest->iNode + 1)
				$aError[] = 'Le nouveau parent doit tre un cran plus haut dans larborescence que le nud  dplacer.';
			else if ($nodeSource->parent->id == $nodeDest->id)
				$aError[] = 'Le nouveau parent ne doit pas tre le parent du nud  dplacer.';
			else if ($nodeSource->sPathPart) {
				if (!$nodeDest->sPathPart)
					$aError[] = 'Le nouveau parent na pas de rpertoire.';
				else{
					$sPathOld = $nodeSource->sPathFull;
					$sPathNew = path::concat($nodeDest->sPathFull, $nodeSource->sPathPart);
					if ($sPathOld) {
						if (hasPrefix($sPathNew, $sPathOld))
							$aError[] = 'Le nouveau chemin daccs (' . html::kbdText($sPathNew) . ') est inclus dans lancien (' . html::kbdText($sPathOld) . ').';
						else if (file_exists($sPathNew))
							$aError[] = 'Le nouveau chemin daccs (' . html::kbdText($sPathNew) . ') existe dj.';
					}
				}
			}
		}
		
		$sSuccess = null;
		if (!$aError) {
			if ($bMove) {
				if ($this->doMove($nodeSource, $nodeDest, $_REQUEST->bInsertAtEnd, $aError))
					$sSuccess = 'Dplacement effectu.';
			}else
				$sSuccess = 'Le dplacement peut tre effectu.';
		}
		
		if ($aError)
			$s .= html::div(html::mapConcat('div', $aError), attr::className('errors'));
		else
			$s .= html::div($sSuccess, attr::className('ok'));
		
		return $s;
	}
	
	
	protected function loadNode($id, $sTitle, &$sInfo, &$aError)
	{
		$node = getNode($id);
		
		$sInfo = html::par(html::b(ucfirst($sTitle) . '&nbsp;:') . ' ' . (($node)
			? $node->dump()
			: html::i('nud inexistant')));
		
		if (!$node)
			$aError[] = 'ID du ' . $sTitle . ' invalide.';
		
		return $node;
	}
	
	
	/// Move a node to a new parent.
	/// @param $nodeSource the node to move.
	/// @param $nodeDest the new parent of the node to move.
	/// @param $bInsertAtEnd if \c false, move the node at first position in the destination node children list.
	/// @param $aError the array to add the errors to.
	/// @return \c true if success, \c false if failure.
	protected function doMove($nodeSource, $nodeDest, $bInsertAtEnd, &$aError)
	{
		if ($nodeSource->sPathPart) {
			$sPathOld = $nodeSource->sPathFull;
			$sPathNew = path::concat($nodeDest->sPathFull, $nodeSource->sPathPart);
			if (!@rename($sPathOld, $sPathNew)) {
				$aError[] .= 'Impossible de renommer ' . html::kbdText($sPathOld) . ' en ' . html::kbdText($sPathNew) . '.';
				return false;
			}
		}
		
		$sTable = node::$table->sName;
		
		sql::lockTables(array($sTable));
		
		if ($bInsertAtEnd) {
			// Insert at the end
			// MAX(iOrder)+1 is NULL if the destination node has no child:
			// this will be converted to 0.
			$iOrderNew = intval(sql::selectOneField($sTable, 'MAX(iOrder)+1',
				sql::whereOne('idParent', $nodeDest->id)));
			
		}else{
			// Insert at the beginning
			$iOrderNew = 0;
			sql::update($sTable, array('!iOrder' => 'iOrder+1'),
				sql::whereOne('idParent', $nodeDest->id));
		}
		
		// Change the parent and the order
		sql::update($sTable, array(
				'idParent' => $nodeDest->id,
				'iOrder'   => $iOrderNew,
			),
			sql::whereId($nodeSource->id));
		
		// Update the order of the old siblings
		sql::update($sTable, array('!iOrder' => 'iOrder-1'),
			sql::where($nodeSource->getBrotherSqlCondition()) . ' AND iOrder>' . $nodeSource->iOrder);
		
		sql::unlockTables();
		
		return true;
	}
}

Page::output(new PageMoveNode);

?>