<?php
// This file is part of DENIF, distributed under license GPLv3.
// Copyright 2006 Guillaume Ryder, Arthur Charguraud

require_once 'shared.inc.php';


class PageHuman extends PageDenif
{
	public $id;
	private $aProperty;
	private $human;
	
	
	protected function getParameters() { return concatLists(parent::getParameters(), 'id'); }
	
	protected function getTitle()
	{
		return
			ucfirst(ObjectTypeInfo::get(propertyHuman)->sAlone) .
			(($this->human) ? '&nbsp;: ' . html::text($this->human->sName) : '');
	}
	
	
	private static function field($sLabel, $sValue)
	{
		return html::div(html::span($sLabel . '&nbsp;:', attr::className('field-label')) . ' ' . $sValue);
	}
	
	
	protected function scripts()
	{
		return parent::scripts() .
			html::jscriptLink('global.js') .
			html::jscriptInline('catchLoad(function() { unobfuscateMail(id("teacher-mail")); });');
	}
	
	
	protected function initialize()
	{
		parent::initialize();
		$this->loadParameters();
		
		$this->aProperty = getAllProperties();
		$this->human = defaultElement($this->aProperty[propertyHuman], $this->id, null);
		if (!$this->human)
			$this->fatalError('Cet enseignant ne figure pas dans la base.');
	}
	
	
	protected function contents()
	{
		$human = $this->human;
		$aLink = sql::selectFetch(getList('link;node'), getList('link.*;iNode'),
			sql::whereOne('!node.id', 'link.idNode'));
		
		// Nodes the human is attached to: docgroups and documents
		$aidDocumentLinked = array();
		$aidDocGroupLinked = array();
		foreach ($aLink as $link) {
			if ($link->iProperty == propertyHuman && $link->idProperty == $human->id) {
				if ($link->iNode == nodeDocument)
					$aidDocumentLinked[] = $link->idNode;
				else if ($link->iNode == nodeDocGroup)
					$aidDocGroupLinked[] = $link->idNode;
			}
		}
		makeUnique($aidDocumentLinked);
		makeUnique($aidDocGroupLinked);
		$nbContrib = count($aidDocumentLinked) + count($aidDocGroupLinked);
		
		// Title
		$aTitlePart = $this->getObjectLinks($human, $human->getAnchor(),
			($nbContrib == 0) ? objectLinksDelete : 0, -1,
			new target('index_teachers.php'));
		$aTitlePart[] = $this->getTitle();
		$s = $this->putTitle(concat($aTitlePart));
		
		// To avoid spamming, do not write the e-mail verbatim
		if ($human->sURL)
			$s .= self::field('Page perso', $this->linkOut($human->sURL, html::kbdText($human->sURL)));
		if ($human->sEmail && $this->isAdmin())
			$s .= self::field('Adresse e-mail', html::kbd(obfuscateMail($human->sEmail), attr::id('teacher-mail')));
		
		$aDocument = ($aidDocumentLinked)
			? getNodes(nodeDocument, 'AND ' .
				sql::formatInIntList('id', $aidDocumentLinked))
			: array();
		
		$aidDocGroup = array_unique(projectTo($aDocument, 'idParent') + $aidDocGroupLinked);
		$aDocGroup = ($aidDocGroup)
			? getNodes(nodeDocGroup, 'AND ' . sql::formatInIntList('id', $aidDocGroup))
			: array();
		
		if ($aidDocGroupLinked)
			append($aDocument, getNodes(nodeDocument,
				'AND ' . sql::formatInIntList('idParent', $aidDocGroupLinked)));
		
		$aSession = getParentNodes(nodeSession, $aDocGroup);
		
		$view = new view($this);
		$view->load(nodeLast + 1, array(
				nodeResource => getParentNodes(nodeResource, $aSession),
				nodeSession  => $aSession,
				nodeDocGroup => $aDocGroup,
				nodeDocument => $aDocument,
			), $this->aProperty, $aLink);
		$view->setFoundNodes(array_flip(array_merge($aidDocumentLinked + $aidDocGroupLinked)));
		
		$sContrib = $view->dump(viewUseHighlighting | viewForceChildren, 3);
		if ($view->getFoundCount() > 0)
			$s .=
				$this->putTitle('Documents rfrencs') .
				html::par('Pour voir les documents dune ressource crits par dautres enseignants, cliquez sur son titre, ou bien sur son icne ' . DenifLink::createAction('#', 'details', 'Dtails')->html() . ' ou ' . html::span(DenifLink::createAction('#', 'details', 'Dtails')->html(), attr::className('needed')) . '.') .
				$sContrib;
		else
			// No linked document is visible
			$s .= html::par('Aucun document nest associ  cet enseignant.');
		
		return $s;
	}
}

Page::output(new PageHuman);

?>