<?php
// This file is part of DENIF, distributed under license GPLv3.
// Copyright 2006 Guillaume Ryder, Arthur Charguraud

require_once 'shared.inc.php';
require_once 'ping_download.php';


defineEnum('wdl', 'Download;Ping;ForcePing;ForceIgnore');

class PageWantDownload extends PageDenif
{
	public $idSource, $sReturnURL;
	
	
	protected function getParameters() { return concatLists(parent::getParameters(), 'idSource;sReturnURL'); }
	
	protected function getTitle() { return 'Tlcharger des documents'; }
	
	protected function getCurrentNodeID() { return $this->idSource; }
	
	
	protected function initialize()
	{
		$_REQUEST->prepare('bTest;bSubmit;bSubmitPingDownload;bPingDownload');
		
		// Default value for 'bProcessCached' is true
		if (!($_REQUEST->bTest || $_REQUEST->bSubmit || $_REQUEST->bSubmitPingDownload))
			$_REQUEST->bProcessCached = true;
		
		parent::initialize();
		$this->loadParameters();
		
		$this->needAdmin();
		
		if ($_REQUEST->bPingDownload)
			PingDownload::executePlainText();
	}
	
	
	protected function contents()
	{
		$s = $this->putTitle('Programmer le ping/tlchargement de documents');
		
		$aAction = array(
			wdlDownload    => 'Demander tlchargement (= 2)',
			wdlPing        => 'Demander ping sans annuler tlchargement (= 1 si &lt; 1)',
			wdlForcePing   => 'Annuler tlchargement puis demander ping (= 1)',
			wdlForceIgnore => 'Annuler ping et tlchargement (= 0)',
		);
		
		// Form
		$form = new FormManager($this);
		$form->pushText('idSource', maxLengthID, 6, 'ID nud anctre', 'Vide pour tous les documents');
		$form->pushCheckbox('bProcessCached', 'Absents du cache seulement', 'Dcocher pour autoriser crasement/mise  jour&nbsp;: ' . html::kbd('bCached = 0'));
		$form->pushCheckbox('bPingOK', 'Pingus avec succs seulement', 'Cocher pour autoriser le ping&nbsp;: ' . html::kbd('bPingOK = 1'));
		$form->pushCheckbox('bNeverPinged', 'Jamais pingus seulement', 'Cocher pour pinguer/tlcharger les nouveaux documents seulement&nbsp;: ' . html::kbd('dtPing = 0'));
		$form->pushText('sSQL', 1000, -1, 'Condition SQL personnalise');
		$form->pushElementLabel('iAction', 'Action',
			form::select('IDiAction', $aAction, $_REQUEST->getSafe('iAction')));
		$form->pushElement('', form::submit('bTest', 'Tester') . ' ' . form::submit('bSubmit', 'Programmer la demande'));
		$form->pushElement('', form::submit('bSubmitPingDownload', 'Programmer puis excuter'));
		if ($this->sReturnURL)
			$form->pushElement('', $this->linkTarget($this->targetFromURL($this->sReturnURL), 'Retour'));
		
		$s .= $this->getSelfTarget(targetSession)->form(form::METHOD_GET,
			form::hidden('sReturnURL', $this->sReturnURL) . $form->html());
		
		// Get the nodes and display information about them
		$aError = array();
		$nodeAncestor = getNode($this->idSource);
		
		$iPingDownload = pdlDownload;
		
		$aTable = array();
		$aWhere = array();
		if ($nodeAncestor) {
			$aWhere[getNodeTable($nodeAncestor->iNode) . '.id'] = $nodeAncestor->id;
			sqlNodesChildren($aTable, $aWhere, $nodeAncestor->iNode, nodeLast);
			$sTable = getNodeTable(nodeLast);
		}else
			$aTable[] = $sTable = 'node';
		
		if ($_REQUEST->bProcessCached)
			$aWhere[$sTable . '.bCached'] = false;
		if ($_REQUEST->bPingOK)
			$aWhere[$sTable . '.bPingOK'] = true;
		if ($_REQUEST->bNeverPinged)
			$aWhere[$sTable . '.dtPing'] = 0;
		$sWhere = sql::where($aWhere);
		
		$sFieldPingDownload = $sTable . '.iPingDownload';
		$aActionSQL = array(
			wdlDownload    => pdlDownload,
			wdlPing        => 'GREATEST(' . $sFieldPingDownload . ', ' . pdlPing . ')',
			wdlForcePing   => pdlPing,
			wdlForceIgnore => pdlIgnore,
		);
		$sNewValue = $aActionSQL[$_REQUEST->iAction];
		$sWhere .= ' AND ' . $sFieldPingDownload . ' <> ' . $sNewValue;
		
		if ($_REQUEST->sSQL)
			$sWhere .= ' AND (' . $_REQUEST->sSQL . ')';
		
		$s .= html::par('Condition&nbsp;: ' . html::kbdText($sWhere));
		
		if ($_REQUEST->bSubmit || $_REQUEST->bSubmitPingDownload) {
			// Process the query
			
			sql::update($aTable, array('!' . $sFieldPingDownload => $sNewValue), $sWhere);
			$nb = sql::getAffectedCount();
			$aCountAttr = attr::className('ok');
			
			if ($_REQUEST->bSubmitPingDownload)
				PingDownload::executePlainText();
			
		}else{
			// Test mode
			$nb = sql::count($aTable, $sWhere);
			$aCountAttr = array();
		}
		
		$s .= html::par('Documents affects&nbsp;: ' . $nb, $aCountAttr);
		
		$s .= $this->putTitle('Lancer le ping/tlchargement');
		
		$s .= html::par($this->linkTarget(
			$this->getSelfTarget(targetSession, array('bPingDownload' => 1)),
			'Excuter'));
		
		return $s;
	}
}


Page::output(new PageWantDownload);

?>